aboutsummaryrefslogtreecommitdiff
path: root/networking/tftp.c
diff options
context:
space:
mode:
Diffstat (limited to 'networking/tftp.c')
-rw-r--r--networking/tftp.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/networking/tftp.c b/networking/tftp.c
index 8e3b0a2dc..7c0ee58d7 100644
--- a/networking/tftp.c
+++ b/networking/tftp.c
@@ -117,8 +117,9 @@ struct globals {
/* u16 TFTP_ERROR; u16 reason; both network-endian, then error text: */
uint8_t error_pkt[4 + 32];
struct passwd *pw;
- /* used in tftpd_main(), a bit big for stack: */
- char block_buf[TFTP_BLKSIZE_DEFAULT];
+ /* Used in tftpd_main() for initial packet */
+ /* Some HP PA-RISC firmware always sends fixed 516-byte requests */
+ char block_buf[516];
char block_buf_tail[1];
#if ENABLE_FEATURE_TFTP_PROGRESS_BAR
off_t pos;
@@ -811,7 +812,7 @@ int tftpd_main(int argc UNUSED_PARAM, char **argv)
) {
goto err;
}
/* Some HP PA-RISC firmware always sends fixed 512-byte requests,
* with trailing garbage.
* Support that by not requiring NUL to be the last byte (see above).
* To make strXYZ() ops safe, force NUL termination:
@@ -811,7 +812,7 @@ int tftpd_main(int argc UNUSED_PARAM, char **argv)
goto err;
}
- /* Some HP PA-RISC firmware always sends fixed 512-byte requests,
+ /* Some HP PA-RISC firmware always sends fixed 516-byte requests,
* with trailing garbage.
* Support that by not requiring NUL to be the last byte (see above).